gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[GNUnet-SVN] [libmicrohttpd] 03/05: MHD_get_timeout(): fixed return of l


From: gnunet
Subject: [GNUnet-SVN] [libmicrohttpd] 03/05: MHD_get_timeout(): fixed return of latest timeout instead of earliest.
Date: Tue, 28 Feb 2017 17:52:23 +0100

This is an automated email from the git hooks/post-receive script.

karlson2k pushed a commit to branch master
in repository libmicrohttpd.

commit abc6bac2fbc1bd5927e1d2827eca2c15365c16b8
Author: Evgeny Grin (Karlson2k) <address@hidden>
AuthorDate: Tue Feb 28 19:23:16 2017 +0300

    MHD_get_timeout(): fixed return of latest timeout instead of earliest.
---
 src/microhttpd/daemon.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/src/microhttpd/daemon.c b/src/microhttpd/daemon.c
index 0b27d2a7..9a345621 100644
--- a/src/microhttpd/daemon.c
+++ b/src/microhttpd/daemon.c
@@ -2995,8 +2995,8 @@ MHD_get_timeout (struct MHD_Daemon *daemon,
          have_timeout = MHD_YES;
        }
     }
-  /* normal timeouts are sorted, so we only need to look at the 'head' */
-  pos = daemon->normal_timeout_head;
+  /* normal timeouts are sorted, so we only need to look at the 'tail' 
(oldest) */
+  pos = daemon->normal_timeout_tail;
   if ( (NULL != pos) &&
        (0 != pos->connection_timeout) )
     {

-- 
To stop receiving notification emails like this one, please contact
address@hidden



reply via email to

[Prev in Thread] Current Thread [Next in Thread]